.. sectnum::
   :start: 3

Demo scripts
============

.. contents:: On this page...
   :local:
   :backlinks: top

Some demo scripts and outputs can be found in the :file:`demo/` folder.

More info coming soon.
